@@ -497,4 +497,15 @@ class fillVars(object, cl_base.glob_attr):
         fullHostName = "%s.%s"%(hostName,domain)
         if fullHostName in replUnixServers:
             return "on"
-        return "off"
\ No newline at end of file
+        return "off"
+
+    def get_sr_jabber_hosts(self):
+        """имена хостов с которыми работает сервис Jabber"""
+        return self.Get("sr_jabber_host")
+
+    def get_sr_jabber_hosts_pass(self):
+        """Текст в ejabberd.cfg - имена хостов с которыми работает сервис"""
+        jabberHosts = self.Get("sr_jabber_hosts")
+        if jabberHosts:
+            return ", ".join(map(lambda x: '"'+x+'"', jabberHosts.split(",")))
+        return ""
