@@ -102,6 +102,12 @@ class Data:
     #ID группы
     ur_group_id = {'mode':"w"}
 
+    #SID группы
+    ur_group_sid = {'mode':"w"}
+
+    #Тип группы
+    ur_group_type = {'mode':"w"}
+
     #Полное имя группы
     ur_group_comment = {'mode':"w"}
 
@@ -139,6 +145,12 @@ class Data:
     # имя компьютера с настроенным сервисом Jabber
     sr_jabber_host = {}
 
+    # имена хостов с которыми работает сервис Jabber
+    sr_jabber_hosts = {}
+ 
+    # Текст в ejabberd.cfg - имена хостов с которыми работает сервис
+    sr_jabber_hosts_pass = {}
+
     # jabber id пользователя
     sr_jabber_user_id = {'mode':"w"}
 
@@ -164,7 +176,7 @@ class Data:
 
     #Название первичной группы компьютера
     sr_samba_machine_group = {'mode':"w",
-                              'value':'Computers'}
+                              'value':'Domain Computers'}
 
     #-----------------------------------------------------
     #Все сервисы Unix
@@ -321,7 +333,7 @@ class Data:
 
     # Calculate плюс версия калкулэйта для записи в заголовок файла
     # объединяемого с профилем
-    cl_ver = {'value':'Calculate-server 2.0.11'}
+    cl_ver = {'value':'Calculate-server 2.0.12'}
 
     #DN LDAP ветки, в котором будут находится служебные ветки
     ld_ldap_dn = {}
